==> kimi_0.1.5-2.tar.gz: kimi-0.1.5/test/global_testcase.c <==
/*
 * Copyright (C) 2008-2009 Petrozavodsk State University
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
#define CTF_LOG_FORMAT_USE_TIME
#define CTF_THROW_EXIT

#include "CTF/src/ctf.h"

GLOBAL();
CTF_TEST_DATA_FILE("../test/test.dat");
CTF_STAT_FILE("../test/test.stat");
CTF_LOG_FILE("../test/test2.log");
CTF_FAIL_LOG_FILE("../test/fail.log");

/* CTF_RUN(date_changed_test(), create_event_test()); */
CTF_RUN(date_changed_test(),
        new_event_test(),
        select_event_test(),
        search_event_test(),
	view_event_test(),
        edit_event_test(),
        create_event_test(),
        alarm_test(),
        alarm_test2(),
        period_test(),
        event_data_access_open_db_with_wrong_filename_test(),
        event_data_access_query_test(),
        
        store_event_test2(),
        store_event_test3(),
        ev_sel_get_next_in_period_test(),
        ev_sel_get_next_in_period_test2()
        
       , 
	event_data_select_test1(),
	        remote_storage_test());

==> kimi_0.2.2-1.tar.gz: kimi-0.2.2/test/global_testcase.c <==
/*
 * Copyright (C) 2008-2009 Petrozavodsk State University
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
#define CTF_LOG_FORMAT_USE_TIME
#define CTF_THROW_EXIT

#include "CTF/src/ctf.h"

GLOBAL();
CTF_TEST_DATA_FILE("../test/test.dat");
CTF_STAT_FILE("../test/test.stat");
CTF_LOG_FILE("../test/test.log");
CTF_FAIL_LOG_FILE("../test/fail.log");

/* CTF_RUN(date_changed_test(), create_event_test()); */
CTF_RUN(
        initialize_module_test(),
        get_event_module_test(),
        store_end_get_test(),
        remove_event_test(),
        date_event_list_test(),
        
        period_test(),
        period_test_2(),
        period_test_3(),
        period_test_4_weekstart(),
        
        get_by_period_test()
        
        
/*        date_changed_test(),

        new_event_test(),
        select_event_test(),
        search_event_test(),
	view_event_test(),
        edit_event_test(),
        create_event_test(),
        alarm_test(),
        alarm_test2(),
        period_test(),
        event_data_access_open_db_with_wrong_filename_test(),
        event_data_access_query_test(),
        
        store_event_test2(),
        store_event_test3(),
        ev_sel_get_next_in_period_test(),
        ev_sel_get_next_in_period_test2()
        
       , 
	event_data_select_test1()*/
	        /*,remote_storage_test()*/
    );
